==> bus-station-3.0.1.tar.gz: bus-station-3.0.1/src/bus_station/passengers/passenger_record/in_memory_passenger_record_repository.py <==
from typing import Any, Dict, Iterable, List, Optional

from bus_station.passengers.passenger_record.passenger_record import PassengerRecord
from bus_station.passengers.passenger_record.passenger_record_repository import PassengerRecordRepository


class InMemoryPassengerRecordRepository(PassengerRecordRepository):
    def __init__(self):
        self.__passenger_records: Dict[str, List[PassengerRecord[Any]]] = {}

    def save(self, passenger_record: PassengerRecord[Any]) -> None:
        if passenger_record.passenger_name in self.__passenger_records:
            self.__passenger_records[passenger_record.passenger_name].append(passenger_record)
            return
        self.__passenger_records[passenger_record.passenger_name] = [passenger_record]

    def find_by_passenger_name(self, passenger_name: str) -> Optional[List[PassengerRecord]]:
        return self.__passenger_records.get(passenger_name)

    def find_by_passenger_name_and_destination(
        self, passenger_name: str, passenger_destination_fqn: str
    ) -> Optional[PassengerRecord]:
        passenger_records = self.__passenger_records.get(passenger_name)
        if passenger_records is None:
            return None

        for passenger_record in passenger_records:
            if passenger_record.destination_fqn == passenger_destination_fqn:
                return passenger_record

        return None

    def all(self) -> Iterable[PassengerRecord[Any]]:
        for passenger_records in self.__passenger_records.values():
            for passenger_record in passenger_records:
                yield passenger_record

    def delete_by_passenger_name(self, passenger_name: str) -> None:
        if passenger_name in self.__passenger_records:
            del self.__passenger_records[passenger_name]

==> bus-station-5.0.0.tar.gz: bus-station-5.0.0/src/bus_station/passengers/passenger_record/in_memory_passenger_record_repository.py <==
from typing import Any, Dict, Iterable, List, Optional

from bus_station.passengers.passenger_record.passenger_record import PassengerRecord
from bus_station.passengers.passenger_record.passenger_record_repository import PassengerRecordRepository


class InMemoryPassengerRecordRepository(PassengerRecordRepository):
    def __init__(self):
        self.__passenger_records: Dict[str, List[PassengerRecord[Any]]] = {}

    def save(self, passenger_record: PassengerRecord[Any]) -> None:
        if passenger_record.passenger_name in self.__passenger_records:
            self.__passenger_records[passenger_record.passenger_name].append(passenger_record)
            return
        self.__passenger_records[passenger_record.passenger_name] = [passenger_record]

    def find_by_passenger_name(self, passenger_name: str) -> Optional[List[PassengerRecord]]:
        return self.__passenger_records.get(passenger_name)

    def find_by_passenger_name_and_destination_name(
        self, passenger_name: str, passenger_destination_name: str
    ) -> Optional[PassengerRecord]:
        passenger_records = self.__passenger_records.get(passenger_name)
        if passenger_records is None:
            return None

        for passenger_record in passenger_records:
            if passenger_record.destination_name == passenger_destination_name:
                return passenger_record

        return None

    def all(self) -> Iterable[PassengerRecord[Any]]:
        for passenger_records in self.__passenger_records.values():
            for passenger_record in passenger_records:
                yield passenger_record

    def delete_by_passenger_name(self, passenger_name: str) -> None:
        if passenger_name in self.__passenger_records:
            del self.__passenger_records[passenger_name]
